"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from kdp_api.api_client import ApiClient, Endpoint as _Endpoint
from kdp_api.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from kdp_api.model.api_error import ApiError
from kdp_api.model.workspace import Workspace
from kdp_api.model.workspace_create_request import WorkspaceCreateRequest
from kdp_api.model.workspace_paginator import WorkspacePaginator
from kdp_api.model.workspace_patch_request import WorkspacePatchRequest
from kdp_api.model.workspace_update_request import WorkspaceUpdateRequest
 


class WorkspacesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.delete_workspaces_id_endpoint = _Endpoint(
            settings={
                'response_type': (Workspace,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/workspaces/{id}',
                'operation_id': 'delete_workspaces_id',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_workspaces_endpoint = _Endpoint(
            settings={
                'response_type': (WorkspacePaginator,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/workspaces',
                'operation_id': 'get_workspaces',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'skip',
                    'sort',
                    'filter',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'skip':
                        (int,),
                    'sort':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                    'filter':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                    'limit': '$limit',
                    'skip': '$skip',
                    'sort': '$sort',
                    'filter': 'filter',
                },
                'location_map': {
                    'limit': 'query',
                    'skip': 'query',
                    'sort': 'query',
                    'filter': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_workspaces_id_endpoint = _Endpoint(
            settings={
                'response_type': (Workspace,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/workspaces/{id}',
                'operation_id': 'get_workspaces_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.patch_workspaces_id_endpoint = _Endpoint(
            settings={
                'response_type': (Workspace,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/workspaces/{id}',
                'operation_id': 'patch_workspaces_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                    'workspace_patch_request',
                ],
                'required': [
                    'id',
                    'workspace_patch_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                    'workspace_patch_request':
                        (WorkspacePatchRequest,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                    'workspace_patch_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.post_workspaces_endpoint = _Endpoint(
            settings={
                'response_type': (Workspace,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/workspaces',
                'operation_id': 'post_workspaces',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'workspace_create_request',
                ],
                'required': [
                    'workspace_create_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'workspace_create_request':
                        (WorkspaceCreateRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'workspace_create_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.put_workspaces_id_endpoint = _Endpoint(
            settings={
                'response_type': (Workspace,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/workspaces/{id}',
                'operation_id': 'put_workspaces_id',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                    'workspace_update_request',
                ],
                'required': [
                    'id',
                    'workspace_update_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                    'workspace_update_request':
                        (WorkspaceUpdateRequest,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                    'workspace_update_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def delete_workspaces_id(
        self,
        id,
        **kwargs
    ):
        """Deletes Workspace with the ID given  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_workspaces_id(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of workspace to remove

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Workspace
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        return self.delete_workspaces_id_endpoint.call_with_http_info(**kwargs)

    def get_workspaces(
        self,
        **kwargs
    ):
        """Retrieves a list of workspaces  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_workspaces(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            limit (int): Number of results to return. [optional]
            skip (int): Number of results to skip. [optional]
            sort ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Property to sort results. [optional]
            filter ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Query parameters to filter. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            WorkspacePaginator
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_workspaces_endpoint.call_with_http_info(**kwargs)

    def get_workspaces_id(
        self,
        id,
        **kwargs
    ):
        """Retrieves Workspace with given ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_workspaces_id(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of workspace to return

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Workspace
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        return self.get_workspaces_id_endpoint.call_with_http_info(**kwargs)

    def patch_workspaces_id(
        self,
        id,
        workspace_patch_request,
        **kwargs
    ):
        """Updates provided fields of Workspace with the ID given  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.patch_workspaces_id(id, workspace_patch_request, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of workspace to update
            workspace_patch_request (WorkspacePatchRequest):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Workspace
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        kwargs['workspace_patch_request'] = \
            workspace_patch_request
        return self.patch_workspaces_id_endpoint.call_with_http_info(**kwargs)

    def post_workspaces(
        self,
        workspace_create_request,
        **kwargs
    ):
        """Creates a new Workspace  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_workspaces(workspace_create_request, async_req=True)
        >>> result = thread.get()

        Args:
            workspace_create_request (WorkspaceCreateRequest):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Workspace
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['workspace_create_request'] = \
            workspace_create_request
        return self.post_workspaces_endpoint.call_with_http_info(**kwargs)

    def put_workspaces_id(
        self,
        id,
        workspace_update_request,
        **kwargs
    ):
        """Updates Workspace with the ID given  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_workspaces_id(id, workspace_update_request, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of workspace to update
            workspace_update_request (WorkspaceUpdateRequest):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Workspace
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        kwargs['workspace_update_request'] = \
            workspace_update_request
        return self.put_workspaces_id_endpoint.call_with_http_info(**kwargs)




"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.jobs_api import JobsApi  # noqa: E501


class TestJobsApi(unittest.TestCase):
    """JobsApi unit test stubs"""

    def setUp(self):
        self.api = JobsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_jobs_id(self):
        """Test case for delete_jobs_id

        Removes the job by given id  # noqa: E501
        """
        pass

    def test_get_jobs(self):
        """Test case for get_jobs

        Retrieves list of Jobs  # noqa: E501
        """
        pass

    def test_get_jobs_id(self):
        """Test case for get_jobs_id

        Retrieve Job with the given ID  # noqa: E501
        """
        pass

    def test_patch_jobs_id(self):
        """Test case for patch_jobs_id

        Updates fields provided for Jobs with the ID given  # noqa: E501
        """
        pass

    def test_post_jobs(self):
        """Test case for post_jobs

        Creates a new Job  # noqa: E501
        """
        pass

    def test_put_jobs_id(self):
        """Test case for put_jobs_id

        Updates Job with the ID given  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.attribute_assignments_api import AttributeAssignmentsApi  # noqa: E501


class TestAttributeAssignmentsApi(unittest.TestCase):
    """AttributeAssignmentsApi unit test stubs"""

    def setUp(self):
        self.api = AttributeAssignmentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_attribute_assignments_id(self):
        """Test case for delete_attribute_assignments_id

        Remove Attribute Assignment with given ID  # noqa: E501
        """
        pass

    def test_get_attribute_assignments(self):
        """Test case for get_attribute_assignments

        Retrieve a list of Attribute Assignments  # noqa: E501
        """
        pass

    def test_get_attribute_assignments_id(self):
        """Test case for get_attribute_assignments_id

        Retrieve Attribute Assignment with the given ID  # noqa: E501
        """
        pass

    def test_patch_attribute_assignments_id(self):
        """Test case for patch_attribute_assignments_id

        Update provided fields of Attribute Assignment by given ID  # noqa: E501
        """
        pass

    def test_post_attribute_assignments(self):
        """Test case for post_attribute_assignments

        Create a new Attribute Assignment  # noqa: E501
        """
        pass

    def test_put_attribute_assignments_id(self):
        """Test case for put_attribute_assignments_id

        Update an Attribute Assignment by given ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


__version__ = "0.30.0"

# import ApiClient
from kdp_api.api_client import ApiClient

# import Configuration
from kdp_api.configuration import Configuration

# import exceptions
from kdp_api.exceptions import OpenApiException
from kdp_api.exceptions import ApiAttributeError
from kdp_api.exceptions import ApiTypeError
from kdp_api.exceptions import ApiValueError
from kdp_api.exceptions import ApiKeyError
from kdp_api.exceptions import ApiException



"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.workspace_invitations_api import WorkspaceInvitationsApi  # noqa: E501


class TestWorkspaceInvitationsApi(unittest.TestCase):
    """WorkspaceInvitationsApi unit test stubs"""

    def setUp(self):
        self.api = WorkspaceInvitationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_workspace_invitations(self):
        """Test case for get_workspace_invitations

        Retrieves a list of workspace invitations  # noqa: E501
        """
        pass

    def test_get_workspace_invitations_id(self):
        """Test case for get_workspace_invitations_id

        Retrieves Workspace Invitation with given ID  # noqa: E501
        """
        pass

    def test_post_workspace_invitations(self):
        """Test case for post_workspace_invitations

        Creates a new workspace invitation  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from kdp_api.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from kdp_api.model.abac_label_parser_paginator import AbacLabelParserPaginator
from kdp_api.model.abac_label_parsers import AbacLabelParsers
from kdp_api.model.abac_label_parsers_list import AbacLabelParsersList
from kdp_api.model.api_error import ApiError
from kdp_api.model.application import Application
from kdp_api.model.application_create_request import ApplicationCreateRequest
from kdp_api.model.application_list import ApplicationList
from kdp_api.model.application_paginator import ApplicationPaginator
from kdp_api.model.application_patch_request import ApplicationPatchRequest
from kdp_api.model.application_required_dataset_access import ApplicationRequiredDatasetAccess
from kdp_api.model.application_update_request import ApplicationUpdateRequest
from kdp_api.model.applications_required_dataset_access import ApplicationsRequiredDatasetAccess
from kdp_api.model.attribute import Attribute
from kdp_api.model.attribute_assignment import AttributeAssignment
from kdp_api.model.attribute_assignment_create_request import AttributeAssignmentCreateRequest
from kdp_api.model.attribute_assignment_list import AttributeAssignmentList
from kdp_api.model.attribute_assignment_paginator import AttributeAssignmentPaginator
from kdp_api.model.attribute_assignment_patch_request import AttributeAssignmentPatchRequest
from kdp_api.model.attribute_assignment_update_request import AttributeAssignmentUpdateRequest
from kdp_api.model.attribute_create_request import AttributeCreateRequest
from kdp_api.model.attribute_list import AttributeList
from kdp_api.model.attribute_paginator import AttributePaginator
from kdp_api.model.attribute_patch_request import AttributePatchRequest
from kdp_api.model.attribute_update_request import AttributeUpdateRequest
from kdp_api.model.authentication import Authentication
from kdp_api.model.authentication_details import AuthenticationDetails
from kdp_api.model.authentication_details_authentication import AuthenticationDetailsAuthentication
from kdp_api.model.authentication_details_authentication_payload import AuthenticationDetailsAuthenticationPayload
from kdp_api.model.authentication_details_user import AuthenticationDetailsUser
from kdp_api.model.authentication_list import AuthenticationList
from kdp_api.model.data_source_params import DataSourceParams
from kdp_api.model.dataset import Dataset
from kdp_api.model.dataset_create_request import DatasetCreateRequest
from kdp_api.model.dataset_current_user_permissions import DatasetCurrentUserPermissions
from kdp_api.model.dataset_list import DatasetList
from kdp_api.model.dataset_paginator import DatasetPaginator
from kdp_api.model.dataset_patch_request import DatasetPatchRequest
from kdp_api.model.dataset_permission import DatasetPermission
from kdp_api.model.dataset_permission_create_request import DatasetPermissionCreateRequest
from kdp_api.model.dataset_permission_list import DatasetPermissionList
from kdp_api.model.dataset_permission_paginator import DatasetPermissionPaginator
from kdp_api.model.dataset_permission_patch_request import DatasetPermissionPatchRequest
from kdp_api.model.dataset_permission_update_request import DatasetPermissionUpdateRequest
from kdp_api.model.dataset_update_request import DatasetUpdateRequest
from kdp_api.model.error_code import ErrorCode
from kdp_api.model.group import Group
from kdp_api.model.group_create_request import GroupCreateRequest
from kdp_api.model.group_list import GroupList
from kdp_api.model.group_membership import GroupMembership
from kdp_api.model.group_membership_create_request import GroupMembershipCreateRequest
from kdp_api.model.group_membership_list import GroupMembershipList
from kdp_api.model.group_membership_paginator import GroupMembershipPaginator
from kdp_api.model.group_membership_patch_request import GroupMembershipPatchRequest
from kdp_api.model.group_membership_update_request import GroupMembershipUpdateRequest
from kdp_api.model.group_paginator import GroupPaginator
from kdp_api.model.group_patch_request import GroupPatchRequest
from kdp_api.model.group_update_request import GroupUpdateRequest
from kdp_api.model.index import Index
from kdp_api.model.index_list import IndexList
from kdp_api.model.index_paginator import IndexPaginator
from kdp_api.model.ingest_create_request import IngestCreateRequest
from kdp_api.model.job import Job
from kdp_api.model.job_list import JobList
from kdp_api.model.job_paginator import JobPaginator
from kdp_api.model.json_record import JsonRecord
from kdp_api.model.lucene_query_request import LuceneQueryRequest
from kdp_api.model.query import Query
from kdp_api.model.read_range_request import ReadRangeRequest
from kdp_api.model.record_batch import RecordBatch
from kdp_api.model.reindex_request import ReindexRequest
from kdp_api.model.segment import Segment
from kdp_api.model.segment_list import SegmentList
from kdp_api.model.segment_paginator import SegmentPaginator
from kdp_api.model.sequence_read_request import SequenceReadRequest
from kdp_api.model.source_types import SourceTypes
from kdp_api.model.source_types_list import SourceTypesList
from kdp_api.model.split_points import SplitPoints
from kdp_api.model.stripe_latest_charge import StripeLatestCharge
from kdp_api.model.stripe_latest_charge1 import StripeLatestCharge1
from kdp_api.model.user import User
from kdp_api.model.user_create_request import UserCreateRequest
from kdp_api.model.user_list import UserList
from kdp_api.model.user_paginator import UserPaginator
from kdp_api.model.user_patch_request import UserPatchRequest
from kdp_api.model.user_update_request import UserUpdateRequest
from kdp_api.model.workspace import Workspace
from kdp_api.model.workspace_create_request import WorkspaceCreateRequest
from kdp_api.model.workspace_invitation import WorkspaceInvitation
from kdp_api.model.workspace_invitation_create_request import WorkspaceInvitationCreateRequest
from kdp_api.model.workspace_invitation_list import WorkspaceInvitationList
from kdp_api.model.workspace_invitation_paginator import WorkspaceInvitationPaginator
from kdp_api.model.workspace_list import WorkspaceList
from kdp_api.model.workspace_management import WorkspaceManagement
from kdp_api.model.workspace_management_reassign import WorkspaceManagementReassign
from kdp_api.model.workspace_paginator import WorkspacePaginator
from kdp_api.model.workspace_patch_request import WorkspacePatchRequest
from kdp_api.model.workspace_subscription import WorkspaceSubscription
from kdp_api.model.workspace_subscription_subscription_item_ids import WorkspaceSubscriptionSubscriptionItemIds
from kdp_api.model.workspace_update_request import WorkspaceUpdateRequest
from kdp_api.model.workspaces_subscription import WorkspacesSubscription
from kdp_api.model.workspaces_subscription_subscription_item_ids import WorkspacesSubscriptionSubscriptionItemIds
from kdp_api.model.write_batch_response import WriteBatchResponse



"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.applications_api import ApplicationsApi  # noqa: E501


class TestApplicationsApi(unittest.TestCase):
    """ApplicationsApi unit test stubs"""

    def setUp(self):
        self.api = ApplicationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_applications_id(self):
        """Test case for delete_applications_id

        Removes Application with the given ID  # noqa: E501
        """
        pass

    def test_get_applications(self):
        """Test case for get_applications

        Retrieves a list of Applications  # noqa: E501
        """
        pass

    def test_get_applications_id(self):
        """Test case for get_applications_id

        Retrieves Application with the given ID  # noqa: E501
        """
        pass

    def test_patch_applications_id(self):
        """Test case for patch_applications_id

        Updates provided fields of Application with the given ID  # noqa: E501
        """
        pass

    def test_post_applications(self):
        """Test case for post_applications

        Create a new Application  # noqa: E501
        """
        pass

    def test_put_applications_id(self):
        """Test case for put_applications_id

        Updates Application with the given ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.group_memberships_api import GroupMembershipsApi  # noqa: E501


class TestGroupMembershipsApi(unittest.TestCase):
    """GroupMembershipsApi unit test stubs"""

    def setUp(self):
        self.api = GroupMembershipsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_group_memberships_id(self):
        """Test case for delete_group_memberships_id

        Deletes the group membership with the given ID  # noqa: E501
        """
        pass

    def test_get_group_memberships(self):
        """Test case for get_group_memberships

        Retrieves a list of group memberships  # noqa: E501
        """
        pass

    def test_get_group_memberships_id(self):
        """Test case for get_group_memberships_id

        Retrieves a group membership with the given id  # noqa: E501
        """
        pass

    def test_patch_group_memberships_id(self):
        """Test case for patch_group_memberships_id

        Updates the provided properties of group membership with the given ID  # noqa: E501
        """
        pass

    def test_post_group_memberships(self):
        """Test case for post_group_memberships

        Create a new group membership  # noqa: E501
        """
        pass

    def test_put_group_memberships_id(self):
        """Test case for put_group_memberships_id

        Updates the group membership with the given ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from kdp_api.api_client import ApiClient, Endpoint as _Endpoint
from kdp_api.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from kdp_api.model.api_error import ApiError
from kdp_api.model.group import Group
from kdp_api.model.group_create_request import GroupCreateRequest
from kdp_api.model.group_paginator import GroupPaginator
from kdp_api.model.group_patch_request import GroupPatchRequest
from kdp_api.model.group_update_request import GroupUpdateRequest
 


class GroupsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.delete_groups_id_endpoint = _Endpoint(
            settings={
                'response_type': (Group,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/groups/{id}',
                'operation_id': 'delete_groups_id',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_groups_endpoint = _Endpoint(
            settings={
                'response_type': (GroupPaginator,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/groups',
                'operation_id': 'get_groups',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'skip',
                    'sort',
                    'filter',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'skip':
                        (int,),
                    'sort':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                    'filter':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                    'limit': '$limit',
                    'skip': '$skip',
                    'sort': '$sort',
                    'filter': 'filter',
                },
                'location_map': {
                    'limit': 'query',
                    'skip': 'query',
                    'sort': 'query',
                    'filter': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_groups_id_endpoint = _Endpoint(
            settings={
                'response_type': (Group,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/groups/{id}',
                'operation_id': 'get_groups_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.patch_groups_id_endpoint = _Endpoint(
            settings={
                'response_type': (Group,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/groups/{id}',
                'operation_id': 'patch_groups_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                    'group_patch_request',
                ],
                'required': [
                    'id',
                    'group_patch_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                    'group_patch_request':
                        (GroupPatchRequest,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                    'group_patch_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.post_groups_endpoint = _Endpoint(
            settings={
                'response_type': (Group,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/groups',
                'operation_id': 'post_groups',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'group_create_request',
                ],
                'required': [
                    'group_create_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'group_create_request':
                        (GroupCreateRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'group_create_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.put_groups_id_endpoint = _Endpoint(
            settings={
                'response_type': (Group,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/groups/{id}',
                'operation_id': 'put_groups_id',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                    'group_update_request',
                ],
                'required': [
                    'id',
                    'group_update_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                    'group_update_request':
                        (GroupUpdateRequest,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                    'group_update_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def delete_groups_id(
        self,
        id,
        **kwargs
    ):
        """Removes the group with the given id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_groups_id(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of group to remove

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Group
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        return self.delete_groups_id_endpoint.call_with_http_info(**kwargs)

    def get_groups(
        self,
        **kwargs
    ):
        """Retrieves a list of groups from the groups service  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_groups(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            limit (int): Number of results to return. [optional]
            skip (int): Number of results to skip. [optional]
            sort ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Property to sort results. [optional]
            filter ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Query parameters to filter. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            GroupPaginator
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_groups_endpoint.call_with_http_info(**kwargs)

    def get_groups_id(
        self,
        id,
        **kwargs
    ):
        """Retrieves a group with the given id from the service  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_groups_id(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of group to return

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Group
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        return self.get_groups_id_endpoint.call_with_http_info(**kwargs)

    def patch_groups_id(
        self,
        id,
        group_patch_request,
        **kwargs
    ):
        """Updates the resource with the given id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.patch_groups_id(id, group_patch_request, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of group to update
            group_patch_request (GroupPatchRequest):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Group
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        kwargs['group_patch_request'] = \
            group_patch_request
        return self.patch_groups_id_endpoint.call_with_http_info(**kwargs)

    def post_groups(
        self,
        group_create_request,
        **kwargs
    ):
        """Create a new group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_groups(group_create_request, async_req=True)
        >>> result = thread.get()

        Args:
            group_create_request (GroupCreateRequest):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Group
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['group_create_request'] = \
            group_create_request
        return self.post_groups_endpoint.call_with_http_info(**kwargs)

    def put_groups_id(
        self,
        id,
        group_update_request,
        **kwargs
    ):
        """Updates the group with given id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_groups_id(id, group_update_request, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of group to update
            group_update_request (GroupUpdateRequest):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Group
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        kwargs['group_update_request'] = \
            group_update_request
        return self.put_groups_id_endpoint.call_with_http_info(**kwargs)




"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.workspaces_api import WorkspacesApi  # noqa: E501


class TestWorkspacesApi(unittest.TestCase):
    """WorkspacesApi unit test stubs"""

    def setUp(self):
        self.api = WorkspacesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_workspaces_id(self):
        """Test case for delete_workspaces_id

        Deletes Workspace with the ID given  # noqa: E501
        """
        pass

    def test_get_workspaces(self):
        """Test case for get_workspaces

        Retrieves a list of workspaces  # noqa: E501
        """
        pass

    def test_get_workspaces_id(self):
        """Test case for get_workspaces_id

        Retrieves Workspace with given ID  # noqa: E501
        """
        pass

    def test_patch_workspaces_id(self):
        """Test case for patch_workspaces_id

        Updates provided fields of Workspace with the ID given  # noqa: E501
        """
        pass

    def test_post_workspaces(self):
        """Test case for post_workspaces

        Creates a new Workspace  # noqa: E501
        """
        pass

    def test_put_workspaces_id(self):
        """Test case for put_workspaces_id

        Updates Workspace with the ID given  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
